#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['birds']

package_data = \
{'': ['*']}

setup(name='birds',
      version='0.0.2',
      description='birds',
      author=None,
      author_email='Alyetama <56323389+Alyetama@users.noreply.github.com>',
      url=None,
      packages=packages,
      package_data=package_data,
     )
